#!/bin/bash
#
# Copyright (c) 2021, kz
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# * Redistributions of source code must retain the above copyright notice, 
#   this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright notice, 
#   this list of conditions and the following disclaimer in the documentation 
#   and/or other materials provided with the distribution.
# * Neither the name of the <organization> nor the names of its contributors 
#   may be used to endorse or promote products derived from this software 
#   without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

MODULE_NAME=px4_drv
CUR=`pwd`

if [ `whoami` != 'root' ]; then
    echo "This script must be run as root"

    exit 1
fi

apt install -y dkms pcscd

INSTALLED_MODULE=$(dkms status | grep px4 | grep installed)
if [ $? -eq 0 ]; then
  INSTALLED_VERSION=$(echo $INSTALLED_MODULE | awk -F ", "  '{print $2}')

  echo 
  echo $MODULE_NAME $INSTALLED_VERSION has been installed as dkms.
  echo 'Check "$ dkms status"'

  echo "If it's unnecessary, you may have got better remove it at first."
  echo "You can remove it with \"\$ dkms remove $MODULE_NAME/$INSTALLED_VERSION --all\"."
  echo 
  echo It continues in 10 seconds...

  sleep 10 
fi
  
WORKDIR=$(mktemp -d)
echo $WORKDIR

cd $WORKDIR
git clone https://github.com/nns779/$MODULE_NAME

PX4_DKMS_VERSION=$(grep PACKAGE_VERSION $MODULE_NAME/dkms.conf | sed -e 's/^.*"\(.*\)"$/\1/')
INSTALL_TARGET_DIR=/usr/src/$MODULE_NAME-$PX4_DKMS_VERSION
PLEX_FIRMWARE=pxw3u4_BDA_ver1x64.zip

pushd $MODULE_NAME/fwtool
make
if [ -f $CUR/$PLEX_FIRMWARE ]; then
  busybox unzip $CUR/$PLEX_FIRMEARE
else
  wget -O- http://plex-net.co.jp/plex/pxw3u4/$PLEX_FIRMWARE | busybox unzip -
fi
./fwtool pxw3u4_BDA_ver1x64/PXW3U4.sys it930x-firmware.bin
cp -a it930x-firmware.bin /lib/firmware/
popd

mkdir -p $INSTALL_TARGET_DIR
if [ $? -ne 0 ]; then
  exit 1
fi

cp -a $WORKDIR/$MODULE_NAME/* $INSTALL_TARGET_DIR

dkms add $MODULE_NAME/$PX4_DKMS_VERSION
dkms build $MODULE_NAME/$PX4_DKMS_VERSION
dkms install $MODULE_NAME/$PX4_DKMS_VERSION

cat <<EOT

The sources of $MODULE_NAME has been installed on $INSTALL_TARGET_DIR
Please reboot the system to complete.

EOT